Learn R Programming

censuspyrID (version 1.0.2)

censuspyrID-package: censuspyrID: Explorer of Indonesian Population Pyramids from Harmonized and Non-Harmonized Census Data

Description

Provides harmonized and non-harmonized population pyramid datasets from the Indonesian population censuses (1971–2020), along with tools for visualization and an interactive 'shiny'-based explorer application. Data are processed from IPUMS International (1971–2010) and the Population Census 2020 (BPS Indonesia).

Arguments

Author

Maintainer: Ari Purwanto Sarwo Prasojo ari.prasojo18@gmail.com (ORCID)

Authors:

See Also