Learn R Programming

censuspyrID (version 1.0.2)

pop5: Population Counts in 5-Year Age Groups from Indonesian Censuses

Description

Population counts in 5-year age groups at the provincial level (subnational level 1), derived from a series of Indonesian population censuses. Data are available in two versions:

  • hpop5 — Harmonized province codes across census years.

  • ypop5 — Original (non-harmonized) province codes as reported in each census.

Both datasets are processed from census samples provided by IPUMS International (1971–2010) and the Population Census 2020. Data processing steps include prorating to allocate missing attributes and smoothing using multiple demographic methods (Arriaga and Karup–King–Newton).

Arguments

Format

Each dataset is a tibble (data frame) with the following variables:

year

Census year.

province_id_h

Harmonized province identifier (in hpop5).

province_id_y

non-harmonized province identifier (in ypop5).

sex

Sex code.

age5

Age group in 5-year intervals.

ns

Unsmoothed population count.

arriaga

Population count smoothed with the Arriaga method.

kkn

Population count smoothed with the Karup–King–Newton method.

  • hpop5: 5,500 observations.

  • ypop5: 6,146 observations.

References

Ruggles, S., Cleveland, L., Lovaton, R., Sarkar, S., Sobek, M., Burk, D., Ehrlich, D., Heimann, Q., Lee, J., & Merrill, N. (2025). Integrated Public Use Microdata Series, International: Version 7.7 (dataset). Minneapolis, MN: IPUMS. tools:::Rd_expr_doi("10.18128/D020.V7.7")

Badan Pusat Statistik (BPS). (2020). Jumlah Penduduk Menurut Wilayah, Kelompok Umur, dan Jenis Kelamin, di INDONESIA – Sensus Penduduk 2020. Retrieved September 4, 2025, from https://sensus.bps.go.id/topik/tabular/sp2020/3

Siegel, J. S., Swanson, D. A., & Shryock, H. S. (Eds.). (2004). The methods and materials of demography (2nd ed). Elsevier/Academic Press.

Aburto, J. M., Kashnitsky, I., Pascariu, M., & Riffe, T. (2022). Smoothing with DemoTools. Available at: https://timriffe.github.io/DemoTools/articles/smoothing_with_demotools.html#references-1

Examples

Run this code
library(dplyr)

# Harmonized data
data(hpop5)
glimpse(hpop5)
head(hpop5)

# Non-harmonized data
data(ypop5)
glimpse(ypop5)
head(ypop5)

Run the code above in your browser using DataLab