Learn R Programming

censuspyrID (version 1.0.2)

smooth_name: Get Smoothing Method Name

Description

Internal helper function to return the name of the smoothing method based on the provided smoothing code.

Usage

smooth_name(smoothing = 1)

Value

A character string with the name of the smoothing method.

Arguments

smoothing

A numeric value indicating the smoothing method:

  • 1 = non-smoothed ("ns")

  • 2 = Arriaga ("arriaga")

  • 3 = Karup–King–Newton ("kkn")